@@ -1,5 +1,5 @@
 package URL::Exists;
-$URL::Exists::VERSION = '0.02';
+$URL::Exists::VERSION = '0.03';
 use 5.006;
 use strict;
 use warnings;
@@ -27,7 +27,7 @@ sub url_exists
 
 =head1 NAME
 
-URL::Exists - function that returns true if URL is present
+URL::Exists - test whether a URL exists, when you don't care about the contents
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ schemes, if there's any demand / interest.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/URL-Exists>
+L<https://github.com/neilb/URL-Exists>
 
 =head1 AUTHOR
 
